#
# spec file for package python-uvloop
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-uvloop
Version:        0.14.0
Release:        bp156.3.5
Summary:        An asyncio event loop on top of libuv
License:        MIT AND Apache-2.0
Group:          Development/Languages/Python
URL:            http://github.com/MagicStack/uvloop
Source:         https://files.pythonhosted.org/packages/source/u/uvloop/uvloop-%{version}.tar.gz
BuildRequires:  %{python_module Cython >= 0.28}
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pyOpenSSL}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libuv)
%python_subpackages

%description
uvloop is a drop-in replacement of the built-in asyncio
event loop.  uvloop is implemented in Cython and uses libuv
under the hood.

%prep
%setup -q -n uvloop-%{version}
# always use cython to generate code
sed -i -e "/self.cython_always/s/False/True/" setup.py
# use system libuv
sed -i -e "/self.use_system_libuv/s/False/True/" setup.py
# To be sure, no 3rd-party stuff
rm -vrf vendor/

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
# https://github.com/MagicStack/uvloop/issues/70
%python_expand rm -vf %{buildroot}%{$python_sitearch}/%{modname}/_testbase.py
%python_expand rm -vf %{buildroot}%{$python_sitearch}/%{modname}/__pycache__/_testbase.*

%check
# Actually the tests are VERY flaky, thus continue even if they fail :(
#%%python_exec setup.py test || :

%files %{python_files}
%license LICENSE-APACHE LICENSE-MIT
%doc README.rst
%{python_sitearch}/*

%changelog
* Wed Nov  6 2019 Matej Cepl <mcepl@suse.com>
- Update to 0.14.0:
  - Add support for Python 3.8
  - numerous bug fixes
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.13.0:
  * Implement Server.start_serving() and related APIs
  * Make Server an asynchronous context manager.
  * Start using high-performance uv_udp_t handle. This
    should result in a significantly faster UDP support.
  * Make address validation faster in udp.sendto().
* Tue May 14 2019 Drew Balliet <aballiet@suse.com>
- Commented out testing since it is timing out at 5400 seconds in build service
* Thu Mar 21 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.12.2
  * Fix circular references in SSL implementation
  * Fix a memory leak in call_later() and call_at()
  * Round (instead of flooring) delay in call_later()
* Thu Feb 28 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.12.1
  * Fix a circular references case in SSL implementation.
  * Cleanup references to callbacks in canceled callback handles.
  * New SSL implementation. The new implementation is faster and
    and more complete, and will become the default SSL implementation
    in asyncio 3.8. This is a significant change that warrants a release
    candidate to make sure it is tested properly.
  * New uvloop.install() helper function.
  * ssl.CertificateError is no longer logged as it's delivered to
    the Protocol.connection_lost() anyways.
  * Improve UDPTransport.sendto() performance.
* Wed Feb 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Distribute again the .c files as they are needed by parts
  of the py app rh#1639457
- Do not distribute the tests
* Thu Oct 25 2018 Tomáš Chvátal <tchvatal@suse.com>
- Tests are flaky, thus continue even if we fail...
* Sun Oct 14 2018 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of description.
* Thu Oct 11 2018 Ondřej Súkup <mimi.vx@gmail.com>
- initial package version 0.11.2
